summaryrefslogtreecommitdiff
path: root/update.php
diff options
context:
space:
mode:
authorDries Buytaert <dries@buytaert.net>2009-09-14 07:33:55 +0000
committerDries Buytaert <dries@buytaert.net>2009-09-14 07:33:55 +0000
commit0b7962ca0168d65cfb6516792ae2af6c26005c20 (patch)
tree2b9b86e3d77913888f74d4b04b41fcda44480896 /update.php
parente1ad90ba40b74ec103b9113e49b9792b2b422d22 (diff)
downloadbrdo-0b7962ca0168d65cfb6516792ae2af6c26005c20.tar.gz
brdo-0b7962ca0168d65cfb6516792ae2af6c26005c20.tar.bz2
- Patch #570572 by winston, David_Rothstein | Shai, Xano, alexanderpas, emmajane, kazar: changed label for user/1 account from 'administrator' to 'site maintenance account'.
Diffstat (limited to 'update.php')
-rw-r--r--update.php11
1 files changed, 6 insertions, 5 deletions
diff --git a/update.php b/update.php
index 856fa5d0c..2c8fbb14b 100644
--- a/update.php
+++ b/update.php
@@ -13,9 +13,10 @@ define('DRUPAL_ROOT', getcwd());
* Point your browser to "http://www.example.com/update.php" and follow the
* instructions.
*
* If you are not logged in as administrator, you will need to modify the access
* check statement inside your settings.php file. After finishing the upgrade,
* be sure to open settings.php again, and change it back to its original state!
*/
/**
@@ -201,12 +202,12 @@ function update_info_page() {
function update_access_denied_page() {
drupal_set_title('Access denied');
- return '<p>Access denied. You are not authorized to access this page. Please log in as the admin user (the first user you created). If you cannot log in, you will have to edit <code>settings.php</code> to bypass this access check. To do this:</p>
+ return '<p>Access denied. You are not authorized to access this page. Please log in using the site maintenance account (the account you created during installation). If you cannot log in, you will have to edit <code>settings.php</code> to bypass this access check. To do this:</p>
<ol>
<li>With a text editor find the settings.php file on your system. From the main Drupal directory that you installed all the files into, go to <code>sites/your_site_name</code> if such directory exists, or else to <code>sites/default</code> which applies otherwise.</li>
<li>There is a line inside your settings.php file that says <code>$update_free_access = FALSE;</code>. Change it to <code>$update_free_access = TRUE;</code>.</li>
<li>As soon as the update.php script is done, you must change the settings.php file back to its original form with <code>$update_free_access = FALSE;</code>.</li>
- <li>To avoid having this problem in future, remember to log in to your website as the admin user (the user you first created) before you backup your database at the beginning of the update process.</li>
+ <li>To avoid having this problem in the future, remember to log in to your website using the site maintenance account (the account you created during installation) before you backup your database at the beginning of the update process.</li>
</ol>';
}
@@ -13,9 +13,10 @@ define('DRUPAL_ROOT', getcwd());
* instructions.
*
- * If you are not logged in as administrator, you will need to modify the access
- * check statement inside your settings.php file. After finishing the upgrade,
- * be sure to open settings.php again, and change it back to its original state!
+ * If you are not logged in using the site maintenance account, you will need
+ * to modify the access check statement inside your settings.php file. After
+ * finishing the upgrade, be sure to open settings.php again, and change it back
+ * to its original state!
*/
/**